clear all
set more off
global path "./"
sysdir set PLUS "${path}/ado"
use"$path/DataBase/final_base", clear

//////////////////////////////////
//////// Figure 2. Arrival Data of Afghan Refugees in Tajikistan in 2023 ///////////
//////////////////////////////////

preserve
g id3=1
collapse (sum) id3, by(modate)
drop if modate==.

la var id "Afghans Inflows to Tajikistan"

line id modate ,  /// 
legend(size(medsmall))  ///
ytitle("Afghans Inflows to Tajikistan") ///
xtitle("Date", size(small)) graphregion(color(white)) bgcolor(white) ///
lcolor(navy) ///
ylabel(0(200)1200, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
tlabel(2017m1(6)2022m12, labsize(small) angle(90) grid glpattern(dash) glcolor(gs13) glwidth(thin)) ///
tline(2020m11, lcolor(red) lpattern(dash)) tlabel(2020m11 "U.S Withdrawal" , add  labsize(*.90))
graph export  "$path/Outputs/Figure2.pdf", replace
restore

*******************************************
*****Table 1. Descriptives Statistics *****
*******************************************
local desc_variables taliban_pr government_pr contested_pr /// Treatment Variables
sd_trust rhypsochost rwelcomed rbelonging /// 
tajikhome friendrefugee friendhost /// Social Capital
educ literate1 educ1_inv educ2 educ3 /// Education
mental_problems dmotivation dsleep dappetite dsuicidal mhealthasst /// Mental Problems
sd_labor employed wage weekly_hrs_work /// Labor
sd_income incometot spendingtot if sample==1
estpost sum  `desc_variables' 
estout using "$path/Outputs/Table1.xls", cells("count mean sd min max") label replace

**********************************************************************
*******Table 2. Descriptive Statistics - Control Variables in Afghanistan*****
**********************************************************************
local desc_variables age male student_af employed_af friends /// Individual Controls (in Afghanistan)
hhsizeafg firm_af house_af dc_af1 dc_af2 dc_af3 /// Household Variables
d_af13 d_af24 d_af56 ///
incometype_af_a incometype_af_b incometype_af_c incometype_af_d ///
incometype_af_e  incometype_af_g   ///
assets_af_a assets_af_b assets_af_c assets_af_d  ///
assets_af_e assets_af_f assets_af_g assets_af_h assets_af_i assets_af_j  ///
assets_af_k assets_af_l assets_af_m assets_af_n assets_af_o assets_af_p ///
assets_af_q assets_af_r assets_af_s if sample==1
estpost sum  `desc_variables'
estout using "$path/Outputs/Table2.xls", cells("count mean sd min max") label replace  

///////////////////////////////////////
////////////////Estimates//////////////
//////////////////////////////////////

global controls age male student_af employed_af friends  hhsizeafg ///
firm_af house_af dc_af1 dc_af2 dc_af3 d_af13 d_af24 d_af56 ///
incometype_af_a incometype_af_b incometype_af_c incometype_af_d ///
incometype_af_e  incometype_af_g   ///
assets_af_a assets_af_b assets_af_c assets_af_d  ///
assets_af_e assets_af_f assets_af_g assets_af_h assets_af_i assets_af_j  ///
assets_af_k assets_af_l assets_af_m assets_af_n assets_af_o assets_af_p ///
assets_af_q assets_af_r assets_af_s 

*************************************************************************
***** Table 3. Impacts of Extremism on Refugee's Integration*************
*************************************************************************
** Panel A. Taliban Exposure
foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' taliban_pr  $controls if sample==1
outreg2 using "$path/Outputs/Table3_A.xls", bdec(3) label keep (taliban_pr) 
}
** Panel B. Contested Territories Exposure
foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' contested_pr  $controls  if sample==1 
outreg2 using "$path/Outputs/Table3_B.xls", bdec(3) label keep(contested_pr) 
}
** Panel C. U.S. - Allies Exposure
foreach trust of varlist sd_trust  sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' government_pr $controls  if sample==1 
sum `trust' if sample==1 
local av_control=r(mean)
outreg2 using "$path/Outputs/Table3_C.xls", bdec(3) label keep(government_pr) ///
addstat("Mean Dependent Variable", `av_control' ) 
}

************************************************************************
***** Table 4. Impacts of Extremism on Education Attainment *******
************************************************************************
** Panel A. Taliban Exposure
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' taliban_pr  $controls
outreg2  using "$path/Outputs/Table4_A.xls", bdec(3) label keep (taliban_pr) 
}

** Panel B. Contested Territories Exposure
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' contested_pr  $controls
outreg2 using "$path/Outputs/Table4_B.xls", bdec(3) label keep (contested_pr)
}
** Panel C. U.S. - Allies Exposure
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' government_pr  $controls
sum `educ' if sample==1 
local av_control=r(mean) 
outreg2 using "$path/Outputs/Table4_C.xls", bdec(3) label keep (government_pr) ///
addstat("Mean Dep. Variable", `av_control' ) 
}

****************************************
***** Table 5. Impacts of Extremism on Mental Health
*********************************************
** Panel A. Taliban Exposure
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst {
reg `health' taliban_pr  $controls if sample==1
outreg2 using "$path/Outputs/Table5_A.xls", bdec(3) label keep (taliban_pr) 
}
** Panel B. Contested Territories Exposure
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst{
reg `health' contested_pr  $controls if sample==1
outreg2 using "$path/Outputs/Table5_B.xls", bdec(3) label keep (contested_pr)
}
** Panel C. U.S. - Allies Exposure
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst{
reg `health' government_pr  $controls if sample==1
sum `health' if sample==1
local av_control=r(mean)
outreg2 using "$path/Outputs/Table5_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Variable", `av_control' ) 
}

****************************************
***** Table 6. Impacts of Extremism on Labor
*********************************************
** Panel A. Taliban Exposure
foreach labor of varlist sd_labor employed lr_wage lr_weekly_hrs_work{
reg `labor' taliban_pr  $controls 
outreg2 using "$path/Outputs/Table6_A.xls", bdec(3) label keep (taliban_pr) 
}
** Panel B. Contested Territories Exposure
foreach labor of varlist sd_labor employed l_wage l_weekly_hrs_work {
reg `labor' contested_pr  $controls  
outreg2 using "$path/Outputs/Table6_B.xls", bdec(3) label keep (contested_pr) 
}
** Panel C. U.S. - Allies Exposure
foreach labor of varlist sd_labor employed lr_wage lr_weekly_hrs_work {
reg `labor' government_pr $controls 
sum `labor' if sample==1
local av_control=r(mean)
outreg2 using "$path/Outputs/Table6_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var", `av_control' ) 
}

**************************************
***Table 7. Income and Consumption***
**************************************
** Panel A. Taliban Exposure
foreach income of varlist sd_income l_incometot l_spendingtot {
reg `income' taliban_pr  $controls 
outreg2 using "$path/Outputs/Table7_A.xls", bdec(3) label keep (taliban_pr) 
}
** Panel B. Contested Territories Exposure
foreach income of varlist sd_income l_incometot l_spendingtot{
reg `income' contested_pr  $controls  
outreg2 using "$path/Outputs/Table7_B.xls", bdec(3) label keep (contested_pr) 
}
** Panel C. U.S. - Allies Exposure
foreach income of varlist sd_income l_incometot l_spendingtot{
reg `income' government_pr $controls 
sum `income' if sample==1
local av_control=r(mean)
outreg2 using "$path/Outputs/Table7_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var", `av_control' ) 
}


*****************************
*******Q-values**************
*****************************
	
*To generate the FDR q-values for each table, please change the line 185 with the table and the line
* 186 with the panel required,
* it produces the q-values corresponding for each of the tables "Tab3, Tab4, Tab5, Tab6, Tab7"


forvalues i=3/7 {
	foreach panelValue in "PanelA" "PanelB" "PanelC"{
		use"$path/DataBase/p-values", clear
		keep if table=="Tab`i'"
		display "Tab`i'"
		keep if panel=="`panelValue'"
		**** Ejemplo para el método conventional del RD-Robust
		encode outcome, g(cod_outcome)
		drop outcome 

		**** Now use Michael Anderson's code for sharpened q-values
		* Collect the total number of p-values tested
		quietly sum pval
		local totalpvals = r(N)

		* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

		quietly gen int original_sorting_order = _n
		quietly sort pval
		quietly gen int rank = _n if pval~=.

		* Set the initial counter to 1 

		local qval = 1

		* Generate the variable that will contain the BKY (2006) sharpened q-values

		gen bky06_qval = 1 if pval~=.

		* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


		while `qval' > 0 {
			* First Stage
			* Generate the adjusted first stage q level we are testing: q' = q/1+q
			local qval_adj = `qval'/(1+`qval')
			* Generate value q'*r/M
			gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
			* Generate binary variable checking condition p(r) <= q'*r/M
			gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
			* Generate variable containing p-value ranks for all p-values that meet above condition
			gen reject_rank1 = reject_temp1*rank
			* Record the rank of the largest p-value that meets above condition
			egen total_rejected1 = max(reject_rank1)

			* Second Stage
			* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
			local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
			* Generate value q_2st*r/M
			gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
			* Generate binary variable checking condition p(r) <= q_2st*r/M
			gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
			* Generate variable containing p-value ranks for all p-values that meet above condition
			gen reject_rank2 = reject_temp2*rank
			* Record the rank of the largest p-value that meets above condition
			egen total_rejected2 = max(reject_rank2)

			* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
			replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
			* Reduce q by 0.001 and repeat loop
			drop fdr_temp* reject_temp* reject_rank* total_rejected*
			local qval = `qval' - .001
		}
			

		quietly sort original_sorting_order
		export delimited  "./Outputs/TabQ`i'_`panelValue'.csv"
		
	}
}



