clear all
set more off
global path "./"
sysdir set PLUS "${path}/ado"

////////////////////////////////////////
//////Appendix A. Data Description//////
///////////////////////////////////////

use"$path/DataBase/final_base", clear

*************************************************
********* Figure A.I :Age Distribution************
**************************************************

g agroup=1 if age<1
replace agroup=2 if age>=1 & age<=4
replace agroup=3 if age>=5 & age<=9
replace agroup=4 if age>=10 & age<=14
replace agroup=5 if age>=15 & age<=19
replace agroup=6 if age>=20 & age<=24
replace agroup=7 if age>=25 & age<=29
replace agroup=8 if age>=30 & age<=34 
replace agroup=9 if age>=35 & age<=39 
replace agroup=10 if age>=40 & age<=44
replace agroup=11 if age>=45 & age<=49 
replace agroup=12 if age>=50 & age<=54 
replace agroup=13 if age>=55 & age<=59 
replace agroup=14 if age>=60 & age<=64 
replace agroup=15 if age>=65 & age<=69 
replace agroup=16 if age>=70 & age<=74 
replace agroup=17 if age>=75 & age<=79 
replace agroup=18 if age>=80

la define agroup ///
1	"<1" 2 "1-4" 3	"5-9" 4	"10-14" 5 "15-19" 6	"20-24" 7 "25-29" 8	"30-34" 9 "35-39" 10 "40-44"  11 "45-49" 12	"50-54" ///
13	"55-59" 14	"60-64" 15	"65-69" 16	"70-74" 17	"75-79" 18	"80+"
la val agroup agroup 

preserve
g id3=1 
collapse (sum) id2, by(agroup male)
reshape wide id2, i(agroup) j(male)
 
rename  id20 fem
rename  id21 male
replace male = -male
g male1 = male 
g fem1 = fem 
gen zero = 0

twoway bar male1 agroup, horizontal bfc(gs7) blc(gs7) || ///
bar fem1 agroup, horizontal bfc(gs11) blc(gs11) || ///
scatter agroup zero, mlabel(agroup) mlabcolor(black) msymbol(none) ///
xtitle("Total Number", size(small)) ytitle("Age Group Number") ///
xlabel(0 "0" -150 "150" -300 "300" -450 "450" -600 "600"  0(150)700, labsize(small)) ///
ytitle("") yscale(noline) ylabel(none) ///
legend(off) text(15 -150 "Male") text(15 180 "Female") ///
graphregion(color(white)) bgcolor(white)
graph export  "$path/Outputs/FigureA1.pdf", replace
restore


***Figure A.2. Refugee Characterization - Individual Characteristics**
foreach var of varlist age yearseduc literate1 student married  {
cibar `var', over1(male)  ciopts(lcolor(red))   ///
barcol(gs6 gs8 gs10 gs12 gs14) barlabel(on) ///	
graphopts(legend(size(small) region(lcolor(black)) row(1) pos(6) keygap(1)) ylabel(, nogrid)  ///
ytitle(`: var label `var'', size(medium) ///
height(8)) graphregion(color(white))  bgcolor(white))  
graph export "$path/Outputs/FigureA2_`var'.pdf", replace
}

******Figures. Before vs. After moving to Tajikistan **********
use"$path/DataBase/final_base", clear

* gen hhsize in Tajikistan
g id3=1
bys submission__id: egen hhsize=total(id3)
* clean student variable
replace student_af=. if age>24
*** nadie de 6 a 13 anos reporto ser estudiante en afghanistan, se imputan las observaciones
replace student_af=0 if age>=6 & age<=13

***Before Moving****
preserve
keep submission__id male hhsizeafg student_af employed_af occupation_af ///
wages_af hours_work_af contract_af assets_af_j assets_af_k
g afghanistan=1 
ren *_af *
ren hhsizeafg hhsize
ren wages wage
ren assets_af_j tv
ren assets_af_k computer
save"afghanistan.dta", replace
restore

***After Moving****
preserve
keep submission__id male hhsize student employed occupation ///
wage hours_work contract assetsuse_tj_j assetsuse_tj_k
replace hours_work=hours_work*5
g afghanistan=0
ren assetsuse_tj_j tv
ren assetsuse_tj_k computer
save"afghanistan0.dta", replace
restore

******************************
*****Create the Panel*********
******************************
use"afghanistan.dta", clear
append using "afghanistan0"

la var employed "Employed [=1]"
la var student "Student [=1]"
la var hhsize "Household Size"
la var afghanistan "Afghanistan [=1]"
la var occupation "Occupation"
la var tv "Number of TV by Household"
la var computer "Number of Computers by Household"

la def occupation 1 "Manager" 2 "Professional" 3 "Technicians" 4 "Clerks" ///
 5 "Services or Sales Worker" 6 "Skilled Agricultural" ///
 7 "Craft worker" 8 "Machine Operators" 9 "Elementary Occupation", replace
la val occupation occupation

la def afghanistan 1 "Afghanistan" 0 "Tajikistan"
la val afghanistan afghanistan

la def male 1 "Male" 0 "Female", replace
la val male male

replace tv=. if tv==15
replace computer=. if computer>6

**Figure A.3. Refugee Characteristics before and after moving to Tajikistan**
foreach var of varlist employed contract hours_work wage student hhsize {
cibar `var', over1(afghanistan) over2(male)  ciopts(lcolor(red))   ///
barcol(gs6 gs8 gs10 gs12 gs14) barlabel(on) ///	
graphopts(legend(size(small) region(lcolor(black)) row(1) pos(6) keygap(1)) ylabel(, nogrid)  ///
ytitle(`: var label `var'', size(medium) ///
height(8)) graphregion(color(white)) bgcolor(white)) 
graph export "$path/Outputs/FigureA3_`var'.pdf", replace
}

erase "afghanistan.dta"
erase "afghanistan0.dta"

*********************************************************************
***************Figure A.4: Refugee Literacy Rate by Gender************
**********************************************************************
use"$path/DataBase/literacy_rate", clear

line adultliteracyratefemale adultliteracyratemale  /// 
adultliteracyrate1524female adultliteracyrate1524male year ,  /// 
legend(size(medsmall))  ytitle("% of Literacy Rate")  /// 
xtitle("Year", size(small))  /// 
legend(cols(2) pos(6) region(lcolor(black))) /// 
xlabel(1979(6)2022, labsize(medium) angle(45)) /// 
xlabel(2001 "U.S Entry" , add labsize(medium)) /// 
xlabel(2021 "U.S. Withdrawal", add labsize(medium))  /// 
xline(2001 2021, lcolor(black) lpattern(dash)) ///
lcolor(dkgreen navy maroon gs8) bgcolor(white)
graph export "$path/Outputs/FigureA4.pdf", replace


***********************************************
***************Figure A.7: Histogram************
***********************************************
use"$path/DataBase/final_base", clear

*Panel A. Taliban Exposure
foreach var of varlist taliban_pr {
histogram `var' if sample==1, freq bgcolor(white) graphregion(color(white)) color(gs6)  ///
ylabel(0(500)3000, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel A. Taliban Exposure, color(black) size(medium))  ///
xlabel(0.2(0.1)0.6, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pa1.pdf", replace
}

*Panel B: Taliban Exposure Zoom-In
foreach var of varlist taliban_pr {
histogram `var' if sample==1 & taliban_pr>0.21, freq bgcolor(white) graphregion(color(white)) color(gs6)   ///
ylabel(0(100)600, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel B. Taliban Exposure, color(black) size(medium))  ///
xlabel(0.2(0.1)0.6, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pb1.pdf", replace
}

*Panel A. Allies Exposure
foreach var of varlist  government_pr  {
histogram `var' if sample==1, freq bgcolor(white) graphregion(color(white)) color(gs6)  ///
ylabel(0(500)3000, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel A. Allies Exposure, color(black) size(medium))  ///
xlabel(0(0.1)0.8, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pa2.pdf", replace
}
*Panel B. Allies Exposure
foreach var of varlist government_pr  {
histogram `var' if sample==1 & government_pr<0.7, freq bgcolor(white) graphregion(color(white)) color(gs6)  ///
ylabel(0(50)500, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel B. Allies Exposure, color(black) size(medium))  ///
xlabel(0(0.1)0.7, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pb2.pdf", replace
}

*Panel A. Contested Territories
foreach var of varlist  contested_pr {
histogram `var' if sample==1, freq bgcolor(white) graphregion(color(white)) color(gs6)  ///
ylabel(0(500)3500, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel A. Contested Territories, color(black) size(medium))  ///
xlabel(0(0.1)0.7, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pa3.pdf", replace
}

*Panel B. Contested Territories
foreach var of varlist  contested_pr {
histogram `var' if sample==1 & contested_pr>0, freq bgcolor(white) graphregion(color(white)) color(gs6)   ///
ylabel(0(25)350, labsize(small) angle(horizontal) grid glpattern(dash) glcolor(gs13) glwidth(thin))  ///
title(Panel B. Contested Territories, color(black) size(medium))  ///
xlabel(0(0.1)0.7, labsize(small)  grid glpattern(dash) glcolor(gs13) glwidth(thin)) 
graph export "$path/Outputs/FigureA7_Pb3.pdf", replace
}


*******************************************************************
***************Figure A.8:  Treatment Variables Correlation******** 
*******************with Conflict Indicators************
******************************************************************
use"$path/DataBase/conflict", clear

tw scatter taliban best || lfit taliban best,  ///
legend(order( 1 "Taliban Exposure"  2 "Fitted Values") ///
 lwidth(black)  rows(2) size(medium) pos(3)) ///
ytitle("Taliban Exposure by Province", size(medium)) ///
 xtitle("Number of Affected and Killed People in Afghanistan", size(medium)) xlabel(0(500)5000,  valuelabel labsize(small)) note(Note: Correlation=0.28***, color(black) size(small) pos(6)) ///
ylabel(0(0.2)1.0, labsize(small)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path/Outputs/FigureA8a.pdf", replace

tw scatter government best if government>0  || lfit government best if government>0 ,  ///
legend(order( 1 "U.S. Allies Exposure"  2 "Fitted Values") ///
lwidth(black)  rows(2) size(medium) pos(3)) ///
ytitle("U.S. Allies Exposure by Province", size(medium)) ///
xtitle("Number of Affected and Killed People in Afghanistan", size(medium)) xlabel(0(500)3500,  valuelabel labsize(small)) note(Note: Correlation=-0.33***, color(black) size(small) pos(6)) ///
ylabel(0(0.2)1.0, labsize(small)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path/Outputs/FigureA8b.pdf", replace

use"$path/DataBase/conflict_idps", clear

tw scatter taliban disp_ind0 || lfit taliban disp_ind0,  ///
legend(order( 1 "Taliban Exposure"  2 "Fitted Values") lwidth(black) rows(2) size(medium) pos(3)) ///
ytitle("Taliban Exposure" "IDPs Province of Origin", size(medium)) ///
xtitle("Number of Individuals Displaced (Thousands)", size(*.9)) xlabel(0(10)130,  valuelabel labsize(small)) ///
note(Note: Correlation=0.23***, color(black) size(small) pos(6))  ///
ylabel(0(0.2)1.0, labsize(small)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path/Outputs/FigureA8c.pdf", replace


tw scatter government disp_ind0 if government>0 || lfit government disp_ind0 if government>0,  ///
legend(order( 1 "U.S. Allies Exposure"  2 "Fitted Values") ///
lwidth(black)  rows(2) size(medium) pos(3)) ///
ytitle("U.S. Allies Exposure" "IDPs Province of Origin", size(medium)) ///
xtitle("Number of Individuals Displaced (Thousands)", size(*.9)) xlabel(0(10)130,  valuelabel labsize(small)) note(Note: Correlation=-0.26***, color(black) size(small) pos(6)) ///
ylabel(0(0.2)1.0, labsize(small)) ///
plotregion(lcolor(none) ilcolor(none) style(none)) bgcolor(white)  graphregion(style(none) color(gs16))
graph export "$path/Outputs/FigureA8d.pdf", replace


////////////////////////////////////////////
/////////////Robustness Tests///////////////
////////////////////////////////////////////
use"$path/DataBase/final_base", clear

global controls age male student_af employed_af friends  hhsizeafg ///
firm_af house_af dc_af1 dc_af2 dc_af3 d_af13 d_af24 d_af56 ///
incometype_af_a incometype_af_b incometype_af_c incometype_af_d ///
incometype_af_e  incometype_af_g   ///
assets_af_a assets_af_b assets_af_c assets_af_d  ///
assets_af_e assets_af_f assets_af_g assets_af_h assets_af_i assets_af_j  ///
assets_af_k assets_af_l assets_af_m assets_af_n assets_af_o assets_af_p ///
assets_af_q assets_af_r assets_af_s 


****************************************************************
***** Table C.1. Extremism Impact on ********************************
*Integration: controlling for Social Desirability Index *******
********************************
foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' taliban_pr  $controls sdi if sample==1
outreg2 using "$path/Outputs/TableC1_A.xls", bdec(3) label keep (taliban_pr) 
}

foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' contested_pr  $controls sdi if sample==1
outreg2 using "$path/Outputs/TableC1_B.xls", bdec(3) label keep (contested_pr)
}

foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' government_pr $controls sdi if sample==1
sum `trust' if sample==1 & sdi!=.
local av_control=r(mean)
outreg2 using "$path/Outputs/TableC1_C.xls", bdec(3) label keep (government_pr) ///
addstat("Mean Dep. Var", `av_control' ) 
}

****************************************
*****Table C.2. Impacts of Extremism on Education Attainment
***Excluding Student and Employment Status from Control Variables*******
***************************************
global new_controls age male firm_af hhsizeafg ///
 house_af dc_af1 dc_af2 dc_af3 d_af13 d_af24 d_af56 ///
incometype_af_a incometype_af_b incometype_af_c incometype_af_d ///
incometype_af_e  incometype_af_g   ///
 assets_af_a assets_af_b assets_af_c assets_af_d  ///
assets_af_e assets_af_f assets_af_g assets_af_h assets_af_i assets_af_j  ///
assets_af_k assets_af_l assets_af_m assets_af_n assets_af_o assets_af_p ///
assets_af_q assets_af_r assets_af_s friends

foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' taliban_pr  $new_controls if sample==1
outreg2 using "$path/Outputs/TableC2_A.xls", bdec(3) label keep (taliban_pr)
}
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' contested_pr  $new_controls if sample==1
outreg2 using "$path/Outputs/TableC2_B.xls", bdec(3) label keep ( contested_pr)
}
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' government_pr  $new_controls if sample==1
sum `educ' if sample==1 
local av_control=r(mean)
outreg2 using "$path/Outputs/TableC2_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var", `av_control' ) 
}

/////////////////////////////////////////////////////////////////////////////////
////// Excluding provinces with more than 50% of Taliban Control in 2017 ////////
////////////////////////////////////////////////////////////////////////////////

***************************************************************
**Table C3.  Impacts of Extremism on Integration Integration***
***************************************************************
foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' taliban_pr  $controls  if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC3_A.xls", bdec(3) label keep (taliban_pr)  
}

foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' contested_pr  $controls  if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC3_B.xls", bdec(3) label keep (contested_pr) 
}

foreach trust of varlist sd_trust  sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost  {
reg `trust' government_pr $controls  if sample==1 & (provinceborn!=11 & provinceborn!=33)
sum `trust' if sample==1 & (provinceborn!=11 & provinceborn!=33)
local av_control=r(mean)
outreg2 using "$path/Outputs/TableC3_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var.", `av_control' )
}


*************************************************************
**Table C.4. Impacts of Extremism on Education Attainment***
*************************************************************
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' taliban_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC4_A.xls", bdec(3) label keep (taliban_pr)
}
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' contested_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC4_B.xls", bdec(3) label keep (contested_pr)
}
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' government_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
sum `educ' if sample==1 & (provinceborn!=11 & provinceborn!=33)
local av_control=r(mean)
outreg2 using "$path/Outputs/TableC4_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var.", `av_control' )
}

*************************************************************
**Table C.5. Impacts of Extremism on Mental Health***
*************************************************************
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst {
reg `health' taliban_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC5_A.xls", bdec(3) label keep (taliban_pr) 
}
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst{
reg `health' contested_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
outreg2 using "$path/Outputs/TableC5_B.xls", bdec(3) label keep (contested_pr)
}
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst{
reg `health' government_pr  $controls if sample==1 & (provinceborn!=11 & provinceborn!=33)
sum `health' if sample==1 & (provinceborn!=11 & provinceborn!=33)
local av_control=r(mean)
outreg2 using "$path/Outputs/TableC5_C.xls", bdec(3) label keep (government_pr) addstat("Mean Dep. Var.", `av_control' )
}


*****************************
*******Q-values**************
*****************************
	
*To generate the FDR q-values for each table, please change the line 408 with the table and the line
* 408 with the panel required,
* it produces the q-values corresponding for each of the tables "TabC1, TabC2, TabC3, TabC4, TabC5"


forvalues i=1/5 {
	foreach panelValue in "PanelA" "PanelB" "PanelC"{
		use"DataBase/p-values_appendix", clear
		keep if table=="TabC`i'"

		keep if panel=="`panelValue'"
		**** Ejemplo para el método conventional del RD-Robust
		encode outcome, g(cod_outcome)
		drop outcome 

		**** Now use Michael Anderson's code for sharpened q-values
		* Collect the total number of p-values tested
		quietly sum pval
		local totalpvals = r(N)

		* Sort the p-values in ascending order and generate a variable that codes each p-value's rank

		quietly gen int original_sorting_order = _n
		quietly sort pval
		quietly gen int rank = _n if pval~=.

		* Set the initial counter to 1 

		local qval = 1

		* Generate the variable that will contain the BKY (2006) sharpened q-values

		gen bky06_qval = 1 if pval~=.

		* Set up a loop that begins by checking which hypotheses are rejected at q = 1.000, then checks which hypotheses are rejected at q = 0.999, then checks which hypotheses are rejected at q = 0.998, etc.  The loop ends by checking which hypotheses are rejected at q = 0.001.


		while `qval' > 0 {
			* First Stage
			* Generate the adjusted first stage q level we are testing: q' = q/1+q
			local qval_adj = `qval'/(1+`qval')
			* Generate value q'*r/M
			gen fdr_temp1 = `qval_adj'*rank/`totalpvals'
			* Generate binary variable checking condition p(r) <= q'*r/M
			gen reject_temp1 = (fdr_temp1>=pval) if pval~=.
			* Generate variable containing p-value ranks for all p-values that meet above condition
			gen reject_rank1 = reject_temp1*rank
			* Record the rank of the largest p-value that meets above condition
			egen total_rejected1 = max(reject_rank1)

			* Second Stage
			* Generate the second stage q level that accounts for hypotheses rejected in first stage: q_2st = q'*(M/m0)
			local qval_2st = `qval_adj'*(`totalpvals'/(`totalpvals'-total_rejected1[1]))
			* Generate value q_2st*r/M
			gen fdr_temp2 = `qval_2st'*rank/`totalpvals'
			* Generate binary variable checking condition p(r) <= q_2st*r/M
			gen reject_temp2 = (fdr_temp2>=pval) if pval~=.
			* Generate variable containing p-value ranks for all p-values that meet above condition
			gen reject_rank2 = reject_temp2*rank
			* Record the rank of the largest p-value that meets above condition
			egen total_rejected2 = max(reject_rank2)

			* A p-value has been rejected at level q if its rank is less than or equal to the rank of the max p-value that meets the above condition
			replace bky06_qval = `qval' if rank <= total_rejected2 & rank~=.
			* Reduce q by 0.001 and repeat loop
			drop fdr_temp* reject_temp* reject_rank* total_rejected*
			local qval = `qval' - .001
		}
			

		quietly sort original_sorting_order
		export delimited  "./Outputs/TabQ`i'_`panelValue'.csv", replace

		}
	}



*******************************************
****Appendix D : Additional Exercises******
*** D.A Impacts by Gender******************
********************************************
use"$path/DataBase/final_base", clear
********************************************************
***** Table D.1. Heterogeneous Impacts on Education *******
******************************************************
foreach trust of varlist educ literate1 educ1_inv educ2 educ3 {
reg `trust' taliban_female taliban_pr female  $controls
lincom taliban_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD1_A.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(taliban_female taliban_pr female)
}

foreach trust of varlist educ literate1 educ1_inv educ2 educ3 {
reg `trust' contested_female contested_pr female  $controls
lincom contested_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD1_B.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(contested_female contested_pr female)
}

foreach trust of varlist educ literate1 educ1_inv educ2 educ3 {
reg `trust' government_female government_pr female  $controls
lincom government_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD1_C.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(government_female government_pr female)
}

********************************************************
***** Table D.2. Heterogeneous Impacts on Integration *******
******************************************************
foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' taliban_female taliban_pr female  $controls
lincom taliban_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD2_A.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(taliban_female taliban_pr female)
}


foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
 sd_tajikhome sd_frefugee sd_fhost {
reg `trust' contested_female contested_pr female  $controls
lincom contested_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD2_B.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(contested_female contested_pr female)
}

foreach trust of varlist sd_trust sdrhypsochost sdrwelcomed sdrbelonging /// 
sd_tajikhome sd_frefugee sd_fhost {
reg `trust' government_female government_pr female  $controls
lincom government_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD2_C.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(government_female government_pr female)
}

****************************
***** Table D.3. Heterogeneous Impacts on Mental Health *******
***************************
foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst {
reg `health' taliban_female taliban_pr female  $controls
lincom taliban_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD3_A.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(taliban_female taliban_pr female)
}

foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst {
reg `health' contested_female contested_pr female  $controls
lincom contested_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD3_B.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(contested_female contested_pr female)
}

foreach health of varlist mental_problems dmotivation dhope dappetite dsuicidal mhealthasst {
reg `health' government_female government_pr female  $controls
lincom government_female+female
local coef=r(estimate)
local se=r(se)
local t `=`coef'/`se''
outreg2 using "$path/Outputs/TableD3_C.xls", less(0) nocons  bdec(3) addstat("Diff. Effect", `coef', "standard error", `se', "t statistic", `t') keep(government_female government_pr female)
}


********************************************************************************
***** Table D4. Heterogeneous Impacts on Education Attainment*******
*********************************************************************************
g age_2017=age-4

foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' taliban_pr  $controls if age_2017<=25
outreg2 using "$path/Outputs/TableD4_A.xls", bdec(3) label keep (taliban_pr)
reg `educ' taliban_pr  $controls if age_2017>25
outreg2 using "$path/Outputs/TableD4_A.xls", bdec(3) label keep (taliban_pr)
}

foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' contested_pr  $controls  if age_2017<=25
outreg2 using "$path/Outputs/TableD4_B.xls", bdec(3) label keep (contested_pr)
reg `educ' contested_pr  $controls  if age_2017>25
outreg2 using "$path/Outputs/TableD4_B.xls", bdec(3) label keep ( contested_pr)
}

foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
reg `educ' government_pr  $controls  if age_2017<=25 
outreg2 using "$path/Outputs/TableD4_C.xls", bdec(3) label keep ( government_pr)
reg `educ' government_pr  $controls  if age_2017>25 
outreg2 using "$path/Outputs/TableD4_C.xls", bdec(3) label keep ( government_pr)
}





















