clear all
set more off
global path "."
sysdir set PLUS "${path}/ado"

**********************************************************************************
****Construction of Taliban, Contested and U.S Allies Exposure Measurements*******
**********************************************************************************
cd"$path/RawData"
use"taliban2017", clear
merge 1:1 last_province using "taliban2018a"
drop _merge
merge 1:1 last_province using "taliban2019a"
drop _merge
merge 1:1 last_province using "taliban2020a"
drop _merge
merge 1:1 last_province using "taliban2021d"
drop _merge

drop if last_province==.

g taliban_pr=(0.2*taliban2017)+(0.2*taliban2018a)+(0.2*taliban2019a)+(0.2*taliban2020a)+(0.2*taliban2021d)
g government_pr=(0.2*government2017)+(0.2*government2018a)+(0.2*government2019a)+(0.2*government2020a)+(0.2*government2021d)
g contested_pr=(0.2*contested2017)+(0.2*contested2018a)+(0.2*contested2019a)+(0.2*contested2020a)+(0.2*contested2021d)

keep last_province taliban_pr government_pr contested_pr
lab var taliban_pr "Taliban Exposure"
lab var government_pr "Contested Territories Exposure"
lab var contested_pr "U.S.-Allies Exposure"

ren last_province provinceborn
la var provinceborn "Province of Birth" 
save"talvar_province_raw", replace


***********************************************************
******* Migration variables of Aghan Refugee Census*******
**********************************************************
use"modul5a_raw", clear

**Clean year and month
** Translate from Dari to English
**https://blogs.transparent.com/dari/2012/11/26/afghan-calendar-and-months-of-the-year-in-dari/

g month_arrival=1 if timearrivalMonth==11
replace month_arrival=2 if timearrivalMonth==12
replace month_arrival=3 if timearrivalMonth==1
replace month_arrival=4 if timearrivalMonth==2
replace month_arrival=5 if timearrivalMonth==3
replace month_arrival=6 if timearrivalMonth==4
replace month_arrival=7 if timearrivalMonth==5
replace month_arrival=8 if timearrivalMonth==6
replace month_arrival=9 if timearrivalMonth==7
replace month_arrival=10 if timearrivalMonth==8
replace month_arrival=11 if timearrivalMonth==9
replace month_arrival=12 if timearrivalMonth==10

la def month_arrival 1 "January" 2 "February" ///
3 "March" 4 "April" 5 "May" 6 "June" ///
7 "July" 8 "August" 9 "September" 10 "October" 11 "November" ///
12 "December"
la val  month_arrival month_arrival

g year_arrival=1966 if timearrivalYear==100
replace year_arrival=1984 if timearrivalYear==82
replace year_arrival=1983 if timearrivalYear==83
replace year_arrival=1986 if timearrivalYear==80
replace year_arrival=1992 if timearrivalYear==74
replace year_arrival=1993 if timearrivalYear==73
replace year_arrival=1994 if timearrivalYear==72
replace year_arrival=1995 if timearrivalYear==71
replace year_arrival=1996 if timearrivalYear==70
replace year_arrival=1997 if timearrivalYear==69
replace year_arrival=1998 if timearrivalYear==68
replace year_arrival=1999 if timearrivalYear==67
replace year_arrival=2000 if timearrivalYear==66
replace year_arrival=2001 if timearrivalYear==65
replace year_arrival=2002 if timearrivalYear==64
replace year_arrival=2003 if timearrivalYear==63
replace year_arrival=2004 if timearrivalYear==62
replace year_arrival=2005 if timearrivalYear==61
replace year_arrival=2006 if timearrivalYear==60
replace year_arrival=2007 if timearrivalYear==59
replace year_arrival=2008 if timearrivalYear==58
replace year_arrival=2009 if timearrivalYear==57
replace year_arrival=2010 if timearrivalYear==56
replace year_arrival=2011 if timearrivalYear==55
replace year_arrival=2012 if timearrivalYear==54
replace year_arrival=2013 if timearrivalYear==53
replace year_arrival=2014 if timearrivalYear==52
replace year_arrival=2015 if timearrivalYear==51
replace year_arrival=2016 if timearrivalYear==50
replace year_arrival=2017 if timearrivalYear==49
replace year_arrival=2018 if timearrivalYear==48
replace year_arrival=2019 if timearrivalYear==47
replace year_arrival=2020 if timearrivalYear==46
replace year_arrival=2021 if timearrivalYear==45
replace year_arrival=2022 if timearrivalYear==44
*** Two observations 2024 and 2025
gen modate = ym(year_arrival, month_arrival) 
format modate %tm 

****Generate unique id
format submission__id %12.0f
egen id=group(submission__id thisIndex)

la var submission__id "Household Number"
la var thisIndex "Individual Number in Household"
la var id "Individual Identifier"

*** Generate last province of residence before migrate to Tajikistan
la var migrated_af "Before coming to Tajikistan, did you reside for at least 3 months in a different district from where was born?"
la var pastresid1_af "Most recent province of residence in Afghanistan before the most recent migration episode to Tajikistan?"

****History of Migration (We have the last three province and the place of born)
**** People who do not a specific province
replace placeborn=. if placeborn>=35
replace migrated_af=2 if (migrated_af==. & placeborn!=.)

g birth_province=placeborn if migrated_af==2
replace birth_province=. if birth_province==98

** No tenemos la variable de presencia del Taliban para antes del 2017 (Perdemos 1,295 observaciones)
drop if year<2017 
*** Cuando tenemos la variable de presencia del Taliban por días, nos quedamos con la primera fecha disponible

keep modate submission__id thisIndex placeborn
ren placeborn provinceborn
merge m:1 provinceborn using "talvar_province_raw" 
drop if _merge!=3
drop _merge
save"talvar_province", replace


*****************************************************************
****Construction of Distance to Tajikistan Measurements**********
*****************************************************************
use"coordinates_province", clear

g distS= [(lat_shir_khan-lat_province)^2 + (long_shir_khan-long_province)^2]^0.5
g distF= [(lat_friendship-lat_province)^2 + (long_friendship-long_province)^2]^0.5
 
gen dist= [0.5*(distS) + 0.5*(distF)] 
g idist= 1/dist
 
keep provinceborn distS distF dist idist

*****Merge Extremism Exposure Measurements
merge 1:m provinceborn using "talvar_province"
drop _merge
save"talvar_province_dist", replace


*************************************************************************************************
****Construction of Final Database with the Afghan refugee survey from the WorldBank **********
*************************************************************************************************
use "modul1_clean (2023_04_04)", clear 
merge 1:1 submission__id thisIndex using "modul2_clean"
drop _merge
merge 1:1 submission__id thisIndex using "modul3_clean"
drop _merge
merge 1:1 submission__id thisIndex using "modul4_clean"
drop _merge
merge m:1 submission__id using "moduls_5b_10_clean(2023_04_04)"
drop _merge

**********************************
**** Clean Socio-Demographics ****
**********************************

** Panel A. Sociodemographics **

lab var age "Age" 

g male=1 if sex==1
replace male=0 if sex==2
la var male "Male [=1]"

g married=1 if marstat==1 | marstat==4
replace married=0 if  marstat==2 | marstat==3 | marstat==5
la var married "Married or Engaged [=1]"

g literate1=1 if literate==1
replace literate1=0 if literate==2
la var literate1 "Literate [=1]"

g educ_level=1 if educlevel==1
replace educ_level=2 if educlevel==2
replace educ_level=3 if educlevel==3 | educlevel==4
replace educ_level=4 if educlevel==5 | educlevel==6 | educlevel==7 | educlevel==8

tab educ_level, g(educ)

la var educ1 "No education [=1]"
la var educ2 "Primary [=1]"
la var educ3 "Secondary [=1]"
la var educ4 "Technical, University or More [=1]"

g student=1 if attendschool==1
replace student=0 if attendschool==2
la var student "Student [=1]"

g ndays_school=dattend
la var ndays_school "Days Attend to School in a Week"

g disability1=disability
replace disability1=0 if disability==2
la var disability1 "Suffer Disability [=1]"

g refugee=0 if migstatus!=.
replace refugee=1 if migstatus==3 | migstatus==4
la var refugee "Refugee or Asylum Seeker [=1]" 

la var documents2 "Passport [=1]"
la var documents4 "Asylum Seeker Certificate [=1]"
la var documents5 "Refugee Card (Not Expired) [=1]"
la var documents6 "Refugee Card (Expired) [=1]"
la var documents8 "Work Permit [=1]"

g hhead=0
replace hhead=1 if relathh==1
la var hhead "Household Head [=1]"

la var relathh "Household Head Relation"

** Panel B. Labor Market **
replace employed=0 if employed==2
la var employed "Employed [=1]"

g hours_work=hours if employed==1
la var hours_work "Hours Work per Day"

g days_work=days if employed==1
la var days_work "Days Work per Week"

replace contract=0 if contract==2
la var contract "Contract [=1]"

tab occupation, g(o)
la var o1 "Occupation: Manager [=1]"
la var o2 "Occupation: Professional [=1]"
la var o3 "Occupation: Technicians [=1]"
la var o4 "Occupation: Clerks [=1]"
la var o5 "Occupation: Services or Sales Worker [=1]"
la var o6 "Occupation: Skilled Agricultural [=1]"
la var o7 "Occupation: Craft Worker [=1]"
la var o8 "Occupation: Machine Operators or Driver [=1]"
la var o9 "Occupation: Elementary Occupation [=1]"

la var wage "Monthly Wage (Somoni)"

**** Panel C. Afghanistan Variables****

g employed_af=0 if workstatus_af!=.
replace employed_af=1 if workstatus_af==1
la var employed_af "Employed in Afghanistan [=1]"

g student_af=0 if workstatus_af!=.
replace student_af=1 if workstatus_af==3
la var student_af "Student in Afghanistan last month [=1]"

tab  occupation_af, g(o_af)
la var o_af1 "Occupation: Manager [=1]"
la var o_af2 "Occupation: Professional [=1]"
la var o_af3 "Occupation: Technicians [=1]"
la var o_af4 "Occupation: Clerks [=1]"
la var o_af5 "Occupation: Services or Sales Worker [=1]"
la var o_af6 "Occupation: Skilled Agricultural [=1]"
la var o_af7 "Occupation: Craft Worker [=1]"
la var o_af8 "Occupation: Plant, Machine Operators or Driver [=1]"
la var o_af9 "Occupation: Elementary Occupation [=1]"

g hours_work_af=hours_af 
la var hours_work_af "Hours Work per Week"

replace contract_af=0 if contract_af==2
la var contract_af "Written Contract[=1]"

la var wages_af "Monthly Wage (Somoni)"
replace wages_af=. if wages_af<0

la var hhsizeafg "Household Size"

replace house_af=0 if house_af==2
la var house_af "Own a Dwelling [=1]"

la var incometype_af_a "Income from Wage Labor (Somoni)"
la var incometype_af_b "Income from Self-employment (Somoni)"
la var incometype_af_c "Income from Livestock or Crops (Somoni)"
la var incometype_af_d "Income from Handcrafted Products (Somoni)"
replace incometype_af_e=incometype_af_e+incometype_af_f
la var incometype_af_e "Income from Remittances (Somoni)"
la var incometype_af_g "Income from a Loan (Somoni) "
la var incometype_af_h "Income from Housing Rent (Somoni)"

replace firm_af=0 if firm_af==2
la var firm_af "Own an Enterprise in Afghanistan [=1]"

**** Panel D. Child Labor****
g child_labor=0 if childlabor==2
replace child_labor=1 if childlabor==1
la var child_labor "Child Labor [=1]"

g child_work=0 if childhhwork==2
replace child_work=1 if childhhwork==1
la var child_work "Child Labor (Paid or Unpaid) [=1]"

g child_water=0 if childwater==2
replace child_water=1 if childwater==1
la var child_water "Child Fetch Water or Firewood for HH [=1]"

g child_chore=0 if childchore==2
replace child_chore=1 if childchore==1
la var child_chore "Child Help with Household Chores  [=1]"

g ch_choreh=childchoreh
la var ch_choreh "N. Hours Child Help with Household Chores"

g meals_children=0 if meals==5 
replace meals_children=1 if meals==1 
replace meals_children=2 if meals==2
replace meals_children=3 if meals==3 
replace meals_children=4 if meals==4
replace meals_children=. if meals==6 
la var meals_children "Total Meals Eaten by Children (Daily)"

**** Panel E. Migration and Networks****
g  mob_res=1 if  mobrestr==1
replace mob_res=0 if  mobrestr==2
la var mob_res "Aware of Refugees Mobility Restrictions [=1]"

la var mobrestopt1 "Restricted Access to Refugee Family and Friends [=1]" 
la var mobrestopt2 "Restricted Refugee Job Access and Economic Means [=1]"
la var mobrestopt3 "No Effects of Refugees Mobility Restrictions [=1]"

g friends=0 if contacttajik==1
replace friends=1 if contacttajik==2 | contacttajik==3 | contacttajik==4 
la var friends "Friends or Relatives before Moving to Tajikistan [=1]"

g intention_return=1 if return==2 | return==3
replace intention_return=0 if return==4 
la var intention_return "Intention to Return to Afghanistan [=1]"

**** Panel F. HOUSING, UTILITIES & HEALTH (At the household level)
tab dwelling, g(d_af)
la var d_af1 "Dwelling: Single Family House [=1]"
la var d_af2 "Dwelling: Part of a Shared House [=1]"
la var d_af3 "Dwelling: Individual Apartment [=1]"
la var d_af4 "Dwelling: Part of a Shared Apartment [=1]"
la var d_af5 "Dwelling: Tent [=1]"
la var d_af6 "Dwelling: Temporary Shelter or Shack [=1]"

**** Organize indicator variables *****
g d_af56=0 if d_af5!=. | d_af6!=.
replace d_af56=1 if  d_af5==1 | d_af6==1
la var d_af56 "Dwelling: Temporary Shelter, Shak or Tent [=1]"

g d_af13=0 if d_af1!=. | d_af3!=.
replace d_af13=1 if  d_af1==1 | d_af3==1
la var d_af13 "Dwelling: Individual Apartment or House [=1]"

g d_af24=0 if d_af2!=. | d_af4!=.
replace d_af24=1 if  d_af2==1 | d_af4==1
la var d_af24 "Dwelling: Shared Apartment or House [=1]"

tab harrangement, g(dc_af)
la var dc_af1 "Dwelling Contract in Afghanistan: Own it [=1]"
la var dc_af2 "Dwelling Contract in Afghanistan: Pay rent or Lease [=1]"
la var dc_af3 "Dwelling Contract in Afghanistan: Consent with the owner [=1]"

g wall_material=0 if wallmat!=.
replace wall_material=1 if wallmat==1
la var wall_material "Concrete and Cement Wall Material [=1]"

g roof_material=0 if roofmat!=.
replace roof_material=1 if roofmat==1
la var roof_material "Concrete Roof Material [=1]"

g rooms_hh=room if rooms<8
la var rooms_hh "Number of Rooms in the Household"

g permanent_toilet=0 if toilet!=.
replace permanent_toilet=1 if toilet==4
la var permanent_toilet "Flush to Piped Sewer System [=1]"

g permanent_electricity=0 if electricity!=.
replace permanent_electricity=1 if electricity==1
la var permanent_electricity "Electric Grid [=1]"

g electricity_cooking=1 if cooking==7 | cooking==6
replace electricity_cooking=0 if cooking==2 | cooking==3 
la var electricity_cooking "Electricity or Gas used for Cooking [=1]"

g piped_water=0 if water!=.
replace piped_water=1 if water==1 | water==2
la var piped_water "Piped Water [=1]"

g public_transport=1 if pubtransp==1 | pubtransp==2
replace public_transport=0 if pubtransp==3 | pubtransp==4
la var public_transport "Easy Access to Public Transport [=1]"

*************************
********Health***********
*************************

g need_health=needhealthcare
la var need_health "Members Required Health Assistance [=1]"

g got_healthcare=1 if gothealthcare==1
replace got_healthcare=0 if gothealthcare==2
la var got_healthcare "Got Healthcare Treatment When Need it [=1]"

g health_pay=1 if healthpay==1
replace health_pay=0 if healthpay==2
la var health_pay "Have to Pay for the Doctor [=1]"

g share_polio= poliovacc/hhmemberCount
la var share_polio "Polio Vaccinated (% Indiv. in HH)"

g share_covid= covidvacc/hhmemberCount if covidvacc<17
la var share_covid "Covid-19 Vaccinated (% Indiv. in HH)"

g pregnant_check=1 if pregnantcheck==1
replace pregnant_check=0 if pregnantcheck==2
la var pregnant_check "Regular Pregnant Check [=1]"

g chronic_check=1 if chroniccheck==1
replace chronic_check=0 if chroniccheck==2
la var chronic_check "Medical Check for Chronic Disease [=1]"

g treatment=1 if treatmentmed==1
replace treatment=0 if treatmentmed==2
la var treatment "Access to Regular Treatment [=1]"

foreach var of varlist desease_a-desease_j {
g s`var'=`var'/hhmemberCount	
}

la var sdesease_a "High Blood Pressure (% Indiv. in HH)"
la var sdesease_b "Diabetes (% Indiv. in HH)"
la var sdesease_c "Cancer (% Indiv. in HH)"
la var sdesease_d "Lung Disease (% Indiv. in HH)" 
la var sdesease_e "Heart Disease (% Indiv. in HH)" 
la var sdesease_f "Blood Disease (% Indiv. in HH)"
la var sdesease_g "STD (% Indiv. in HH)"
la var sdesease_h "Tuberculosis (% Indiv. in HH)"
la var sdesease_i "Asthma (% Indiv. in HH)"
la var sdesease_j "Mental Health (% Indiv. in HH)"

*************************
********Income***********
*************************
la var incometype_a "Income from Wage Labor (Somoni)"
la var incometype_b "Income from Self-employment (Somoni)"
la var incometype_c "Income from Livestock or Crops (Somoni)"
la var incometype_d "Income from Handcrafted Products (Somoni)"
replace incometype_e=incometype_e+incometype_f
la var incometype_e "Income from Remittances (Somoni)"
la var incometype_g "Income from a Loan (Somoni)"
la var incometype_h "Income from Housing Rent (Somoni)"
la var incometype_i "Income from Cash Transfers (Somoni)"
la var incometype_j "Income from Food Vouchers (Somoni)"
la var incometype_k "Income from Free Shelter (Somoni)"
la var incometype_l "Income from in Kind Food Transfers (Somoni)"
la var incometype_m "Income from in Kind Non-Food Transfers  (Somoni)"
la var incometype_n "Income from Childcare Allowance from Government (Somoni)"
la var incometype_o "Income from Unemployment Benefits (Somoni)"
la var incometype_p "Income from Sale of Assets (Somoni)"
la var incometype_q "Income from Pensions (Somoni)"
la var incometype_r "Income from Zakat Payment (Somoni)"
la var incometype_s "Income from Dowry Payment (Somoni)"

la var incometot "Monthly House Income (Somoni)"
la var spendingtot "Monthly Consumption (Somoni)"

g enough_food=1 if enoughfood==1
replace enough_food=0 if enoughfood==2
la var enough_food "Able to Buy Enough Food [=1]"

g pay_utilities=0 if payutilities==1 
replace pay_utilities=1 if payutilities==2 
la var pay_utilities "Able to Pay Utilities [=1]"

la var rentdebt "Rental Debt (Somoni)"
la var totdebt "Total Debt (Somoni)"


foreach var of varlist hhpoor satisfiedlife {
g r`var'=1 if `var'==4
replace r`var'=2 if `var'==3
replace r`var'=3 if `var'==2
replace r`var'=4 if `var'==1

}

la var rhhpoor "Agree: My Household is Poor (1-4)"
la var rsatisfiedlife "Agree: Satisfaction with Life (1-4)"

***********************************************************
********Trust, Social Cohesion and Mental Health***********
***********************************************************


foreach var of varlist trustneighbor trustrefugee trusthost safety hypsocrefugee hypsochost welcomed belonging {
g r`var'=1 if `var'==5
replace r`var'=2 if `var'==4
replace r`var'=3 if `var'==3
replace r`var'=4 if `var'==2
replace r`var'=5 if `var'==1
la def r`var' 1 "Strongly Disagree" 2 "Disagree" 3 " Neither agree nor disagree" 4 "Agree" 5 "Strongly Agree"
la val r`var' r`var'
}

la var rtrustneighbor "Pop. in this Neighborhood is Trustworthy (1-5)"
la var rtrustrefugee "Pop. in the Refugee Community is Trustworthy (1-5)"
la var rtrusthost "Pop. in the Host Community is Trustworthy (1-5)"
la var rsafety "Feel Safe if you went to Town Centre by Yourself (1-5)"
la var rhypsocrefugee "Feel Comfortable if your Child Socialize with Refugee Children (1-5)"
la var rhypsochost "Feel Comfortable if your Child Socialize with Children of Host Community (1-5)"
la var rwelcomed "Feel Welcomed in this City (1-5)"
la var rbelonging "Feel Part of this Village (1-5)"

foreach var of varlist rtrustneighbor rtrustrefugee rtrusthost rsafety rhypsocrefugee rhypsochost rwelcomed rbelonging {
egen sd`var'=std(`var')
}

la var sdrtrustneighbor "Pop. in this Neighborhood is Trustworthy (SD)"
la var sdrtrustrefugee "Pop. in the Refugee Community is Trustworthy (SD)"
la var sdrtrusthost "Pop. in the Host Community is Trustworthy (SD)"
la var sdrsafety "Feel Safe if you went to Town Centre by Yourself (SD)"
la var sdrhypsocrefugee "Feel Comfortable if your Child Socialize with Refugee Children (SD)"
la var sdrhypsochost "Feel Comfortable if your Child Socialize with Children of Host Community (SD)"
la var sdrwelcomed "Feel Welcomed in this City (SD)"
la var sdrbelonging "Feel Part of this Village (SD)"
la var friendrefugee "Number of Refugee Friends"
la var friendhost "Number of Tajikistan Friends"
replace friendhost=. if friendhost>70

egen sd_tajikhome=std(tajikhome)
la var sd_tajikhome "Feel that Tajikistan is your Home (SD)"

egen sd_frefugee=std(friendrefugee)
egen sd_fhost=std(friendhost)

la var sd_frefugee "Number of Refugee Friends (SD)"
la var sd_fhost "Number of Tajikistan Friends (SD)"


egen trust=rowmean(sdrhypsochost sdrwelcomed sdrbelonging sd_tajikhome sd_frefugee sd_fhost)
egen sd_trust=std(trust)

la var sd_trust "Social Capital Index (SD)"


foreach var of varlist interact {
g r`var'=0 if `var'==5 | `var'==4
replace r`var'=1 if `var'==1 | `var'==2 | `var'==3
}

la var rinteract "Interact Frequently with Tajik Households [=1]"

************************
*** Mental Health ******
************************

foreach var of varlist hapiness {
g r`var'=1 if `var'==4
replace r`var'=2 if `var'==3
replace r`var'=3 if `var'==2
replace r`var'=4 if `var'==1
}
egen sd_hapiness=std(rhapiness)
la var sd_hapiness "Feel Happy (SD)"

foreach var of varlist motivation hope sleep ///
 energy appetite feelbad concentration speakmove suicidal {
 replace `var'=. if `var'==99
 egen sd`var'=std(`var')
}

la var motivation "Felt Little Interest in Doing Things (1-4)"
la var hope "Felt Depressed or Hopeless (1-4)"
la var sleep "Had Sleeping Troubles (1-4)"
la var energy "Felt Tired (1-4)"
la var appetite "Had Poor Appetite or Overeating (1-4)"
la var feelbad "Felt Bad about Yourself (1-4)"
la var concentration "Had Concentrating Troubles (1-4)"
la var speakmove "Moved or Spoken Slowly (1-4)"
la var suicidal " Suicidal Thoughts (1-4)"

la var sdmotivation "Felt Little Interest in Doing Things (SD)"
la var sdhope "Felt Depressed or Hopeless (SD)"
la var sdenergy "Felt Tired (SD)"
la var sdappetite "Had Poor Appetite or Overeating (SD)"
la var sdfeelbad "Felt Bad about Yourself (SD)"
la var sdconcentration "Had Concentrating Troubles (SD)"
la var sdspeakmove "Moved or Spoken Slowly (SD)"
la var sdsuicidal " Suicidal Thoughts (SD)"

foreach var of varlist motivation hope sleep ///
 energy appetite feelbad concentration speakmove suicidal {
g d`var'=0 if `var'==1 | `var'==2
replace d`var'=1 if `var'==3 | `var'==4 
}

la var dmotivation "Felt Little Interest in Doing Things [=1]"
la var dhope "Felt Depressed or Hopeless [=1]"
la var dappetite "Had Poor Appetite or Overeating [=1]"
la var dfeelbad "Felt Bad about Yourself [=1]"
la var dconcentration "Had Concentrating Troubles [=1]"
la var dspeakmove "Moved or Spoken Slowly [=1]"
la var dsuicidal " Suicidal Thoughts [=1]"
la var dsleep "Had Sleeping Troubles [=1]"

replace mhealthasst=0 if mhealthasst==2
la var mhealthasst "Mental Health Assistance [=1]"

egen sdassist=std(mhealthasst)
egen mental=rowmean(sdmotivation sdhope sdappetite sdsuicidal sdassist)
egen sd_mental=std(mental)
lab var sd_mental "Mental Problems Index (SD)"

egen mental_problems=rowmean(dmotivation dhope dappetite dsuicidal mhealthasst)
lab var mental_problems "Mental Health Issues Index"

///////// Education and Trust ////////////
g educ1_inv=1-educ1
la var educ1_inv "Some Education [=1]"
egen educ=rowmean(literate1 educ1_inv educ2 educ3)
la var educ "Education Index"

***Extra clean ()
foreach educ of varlist educ literate1 educ1_inv educ2 educ3  {
	replace `educ'=. if student_af==. & employed_af==.
}

*************************
********Gender***********
*************************

**clean other option

replace decwagehhh=. if decwagehhh==4
replace decwagehhh=3 if decwagehhhx=="family" | decwagehhhx=="with wife" | ///
decwagehhhx=="withfamily" |  decwagehhhx=="with mother"  | decwagehhhx=="with haouse hold"  | ///
decwagehhhx=="with everyones advice" |  decwagehhhx=="together"  | decwagehhhx=="son and mother" | ///
| decwagehhhx=="mother and father"  | decwagehhhx=="mother" | ///
decwagehhhx=="household with  children" |  decwagehhhx=="father and mother"  | decwagehhhx=="family" | ///
| decwagehhhx=="daughter and son in law" | ///
decwagehhhx=="all family"  | ///
decwagehhhx=="household with daughter / husband was dead" | decwagehhhx=="with family"

******* 
g wspend_female=0 if decwagehhh!=.
replace wspend_female=1 if (decwagehhh==2 & male==0) | (decwagehhh==1 & male==0)
replace wspend_female=1 if  decwagehhhx=="doughter"  | /// 
decwagehhhx=="daugther is  household"  | decwagehhhx=="sister and sister" | ///
decwagehhhx=="her husband was dead, live with daugther"

la var wspend_female "Woman decide How the Household Head Money will be Used [=1]"

*********
replace dechhpur=. if dechhpur==4
replace dechhpur=3 if dechhpurx=="2 person" | dechhpurx=="family" | dechhpurx=="family daughter" ///
| dechhpurx=="father mother" | dechhpurx=="house hold" | dechhpurx=="mother father" ///
| dechhpurx=="together" | dechhpurx=="with children" 
*******
g female_purchase=0 if dechhpur!=.
replace female_purchase=1 if (dechhpur==2 & male==0) | (dechhpur==1 & male==0)
replace female_purchase=1 if  dechhpurx=="daughter"  | /// 
dechhpurx=="mother"  | dechhpurx=="sister and sister" 
replace female_purchase=1 if (dechhpurx=="him/her self" & male==0) | (dechhpurx=="his/her self" & male==0)  
 
la var female_purchase "Woman Makes Decisions about Household Purchases [=1]"

*********
replace decvisits=. if decvisits==4
replace decvisits=3 if decvisitsx=="family" | decvisitsx=="father mother" | decvisitsx=="house hold" ///
| decvisitsx=="togetere" | decvisitsx=="together" | decvisitsx=="togethere" ///
| decvisitsx=="with advices" | decvisitsx=="with children" | decvisitsx=="with mother"

g female_decisions=0 if decvisits!=.
replace female_decisions=1 if (decvisits==2 & male==0) | (decvisits==1 & male==0)
replace female_decisions=1 if  decvisitsx=="daughter"  | /// 
decvisitsx=="grand mother"  | decvisitsx=="mother" | decvisitsx=="mother in law" | decvisitsx=="mothers" /// 
| decvisitsx=="sister and sister" 

replace female_decisions=1 if (decvisitsx=="him/her self" & male==0) | (decvisitsx=="his/her self" & male==0)  
la var female_decisions "Woman Makes Decisions about Household Visits [=1]"

*********

replace dechealtheduc=. if dechealtheduc==4
replace dechealtheduc=3 if dechealtheducx=="family" | dechealtheducx=="father mother" | ///
dechealtheducx=="house hold /son" ///
| dechealtheducx=="parviz son of family" | dechealtheducx=="together" | dechealtheducx=="togethere" ///
| dechealtheducx=="with daugther" | dechealtheducx=="with mother" 

************ 
g female_services=0 if dechealtheduc!=.
replace female_services=1 if (dechealtheduc==2 & male==0) | (dechealtheduc==1 & male==0)
replace female_services=1 if  dechealtheducx=="mother"  | /// 
dechealtheducx=="sister abd sister"  | dechealtheducx=="sisters get togethere advice" 

replace female_services=1 if (decvisitsx=="him/her self" & male==0) | (decvisitsx=="his/her self" & male==0) ///  
 | (decvisitsx=="self" & male==0)
la var female_services "Woman Makes Decisions about Health and Education Expenditures [=1]"

*********************************************************************
*******************************************************************
*********************************************************************

foreach var of varlist womanchoice girlsschooling womenwork {
g r`var'=1 if `var'==5
replace r`var'=2 if `var'==4
replace r`var'=3 if `var'==3
replace r`var'=4 if `var'==2
replace r`var'=5 if `var'==1
la def r`var' 1 "Strongly Disagree" 2 "Disagree" 3 " Neither agree nor disagree" 4 "Agree" 5 "Strongly Agree"
la val r`var' r`var'
}

la var rwomanchoice "Woman Should Decide How to Spend his Free Time on His Own (1-5)"
la var rgirlsschooling "Girls Ages 12-16 Have a Right to Go to School (1-5)"
la var rwomenwork "Women Have a the Right to Work outside the Household (1-5)"

replace prioritymen=. if prioritymen==96 | prioritymen==99
replace womanearnmore=. if womanearnmore==96 | womanearnmore==99

la var prioritymen "Men Should Not Have More Right to a Job than Women (1-5)"
la var womanearnmore "If a Woman Earns More Money than Her Husband, Do not Cause Problems (1-5)"


foreach var of varlist rwomanchoice rgirlsschooling rwomenwork prioritymen womanearnmore{
egen sd_`var'=std(`var')
}


la var sd_rwomanchoice "Woman Should Decide How to Spend his Free Time on His Own (SD)"
la var sd_rgirlsschooling "Girls Ages 12-16 Have a Right to Go to School (SD)"
la var sd_rwomenwork "Women Have a the Right to Work outside the Household (SD)"
la var sd_prioritymen "Men Should Have Equal Right to a Job than Women (SD)"
la var sd_womanearnmore "Women Can Earn More Money than Her Husband (SD)"

egen woman_index_=rowmean(sd_rwomanchoice sd_rgirlsschooling sd_rwomenwork sd_prioritymen sd_womanearnmore)
egen woman_index=std(woman_index_)
la var woman_index "Woman Index (SD)"


g women_hhchores=0 if hhchords!=.
replace women_hhchores=1 if (hhchords==1 & male==0) | (hhchords==2 & male==0) | hhchords==4
replace women_hhchores=. if hhchords==99
la var women_hhchores "Household Women are in Charge of Household Chores [=1]"


g ch_chores=1 if ch_malehhcare==1
replace ch_chores=0 if ch_malehhcare==2
la var ch_chores "Males Helped More with Household Chores in Tajikistan [=1]"

g ch_work=1 if ch_womenwork==1
replace ch_work=0 if ch_womenwork==2
la var ch_work "Males are More Willing to let Women Work Outside [=1]"


egen women_decisions=rowmean(wspend_female female_purchase female_decisions female_services) 
la var women_decisions "Women Make Decisions Index"

*=================
* 4 - scale Index
*=================

gen SD1=1 if socialdesbias1==2
replace SD1=0 if socialdesbias1==1 

gen SD2=1 if socialdesbias2==2
replace SD2=0 if socialdesbias2==1 

gen SD3=1 if socialdesbias3==1
replace SD3=0 if socialdesbias3==2 

gen SD4=1 if socialdesbias4==1
replace SD4=0 if socialdesbias4==2 

gen SD5=1 if socialdesbias5==0
replace SD5=0 if socialdesbias5==1 

*INDEX
egen sdi_ = rowtotal(SD1 SD2 SD3 SD4 SD5)
egen sdi=std(sdi_)
label var sdi_ "Social desirability index"
label var sdi "Social desirability index"


*******************************************
**** Objective Measurement - Arreglar *****
*******************************************

foreach var of varlist student employed contract {
	g fem`var'=1 if (`var'==1 & male==0) & employed!=.
	replace fem`var'=0 if (`var'==0) | (`var'==1 & male==1) & employed!=.
	}

la var femstudent "Women Student [=1]" 
la var fememployed "Women with Employed [=1]"
la var femcontract "Women with Labor Contract [=1]"

drop district

**********************************************
************* Merge Instruments **************
*********************************************

merge 1:1 submission__id thisIndex using "talvar_province_dist"
drop _merge
merge 1:1 submission__id thisIndex using "inst_district"
drop _merge


la def provinceborn 1 "Badakhshan"  2 "Badghis" 3 "Baghlan" 4 "Balkh" 5 "Bamyan" ///
6 "Daykundi"  7 "Farah" 8 "Faryab" 9 "Ghazni" 10 "Ghor" ///
11 "Helmand"  12 "Herat" 13 "Jawzjan" 14 "Kabul" 15 "Kandahar" ///
16 "Kapisa"  17 "Khost" 18 "Kunarha" 19 "Kunduz" 20 "Laghman" ///
21 "Logar"  22 "Nangarhar" 23 "Nimroz" 24 "Nooristan" 25 "Paktya" ///
26 "Paktika"  27 "Panjsher" 28 "Parwan" 29 "Samangan" 30 "Sar-e-Pul" ///
31 "Takhar"  32 "Urozgan" 33 "Wardak" 99 "Zabul" 

la val provinceborn provinceborn
 
 **********************************************************
 **************** Extra Clean *****************************
 **********************************************************
 ** Por el distritio reportado, imputar el código de la provincia para los que tienen missing
replace provinceborn=14 if (province=="Kabul" & provinceborn==.)
replace provinceborn=29 if (province=="Samangan" & provinceborn==.)
replace provinceborn=4 if (province=="Balkh" & provinceborn==.)
replace provinceborn=13 if (province=="Jawzjan" & provinceborn==.)
replace provinceborn=12 if (province=="Herat" & provinceborn==.)
replace provinceborn=15 if (province=="Kandahar" & provinceborn==.)
replace provinceborn=31 if (province=="Takhar" & provinceborn==.)
replace provinceborn=33 if (province=="Wardak" & provinceborn==.)
replace provinceborn=1 if (province=="Badakhshan" & provinceborn==.)
replace provinceborn=3 if (province=="Baghlan" & provinceborn==.)

la var taliban_pr "Taliban Exposure"
la var government_pr "Allies Exposure"
la var contested_pr "Contested Territories"
la var idist "Inverse of Distance to Tajikistan"


***** Labor and consumption variables

g sample=1 if taliban_pr!=. & government_pr!=. & contested_pr!=. & student_af!=.
gen year = yofd(dofm(modate))

g weekly_hrs_work=hours_work*7
	 
replace wage=0 if wage==.
replace weekly_hrs_work=0 if weekly_hrs_work==.

foreach var of varlist wage weekly_hrs_work {
g lr_`var'= log(`var'+(`var'^2+1)^0.5)
}

foreach var of varlist weekly_hrs_work wage {
g l_`var'=ln(`var')	
}

foreach var of varlist employed lr_wage lr_weekly_hrs_work {
egen sd`var'=std(`var')	
}

egen labor=rowmean(sdemployed sdlr_wage sdlr_weekly_hrs_work)
egen sd_labor=std(labor)


foreach var of varlist incometot spendingtot {
g l_`var'=ln(`var')	
}

foreach var of varlist l_incometot l_spendingtot {
egen sd`var'=std(`var')	
}

egen income=rowmean(sdl_incometot sdl_spendingtot)
egen sd_income=std(income)

***Integration
la var sd_trust "Integration index (SD)"
la var rhypsochost "Feel comfortable if your child socialize with host children (1-5)" 
la var rwelcomed "Feel welcomed in this city (1-5)"
la var rbelonging "Feel part of this village (1-5)"
la var tajikhome "Feel that Tajikistan is your home (1-5)"
la var friendrefugee "Number of refugee friends" 
la var friendhost "umber of Tajikistan friends"
*** Health
la var mental_problems "Mental health issues index"
la var dmotivation "Felt little interest in doing things [=1]"
la var dsleep "Had sleeping troubles [=1]"
la var dappetite "Had poor appetite or overeating [=1]"
la var dsuicidal "Suicidal thoughts [=1]"
la var mhealthasst "Mental health assistance [=1]"
*** Labor and Income
la var sd_labor "Labor index (SD)"
la var employed "Employed [=1]"
la var wage "Monthly wage (somoni)"
la var weekly_hrs_work "Weekly hours worked (somoni)"
la var sd_income "Income and consumption index (SD)"
la var incometot "Monthly house income (somoni)"
la var spendingtot "Monthly consumption (somoni)"
*** Household Variables
la var student_af "Student before migrating [=1]" 
la var employed_af "Employed [=1]"
la var friends "Friends in Tajikistan (before moving) [=1]"
la var firm_af "Own an enterprise in Afghanistan [=1]"
la var house_af "Own a dwelling [=1]"
la var dc_af1 "Dwelling contract: own it [=1]"
la var dc_af2 "Dwelling contract: pay rent or lease [=1]"
la var dc_af3 "Dwelling contract: consent with the owner [=1]"
la var d_af13 "Dwelling: individual apartment or house [=1]"
la var d_af24 "Dwelling: apartment or house [=1]"
la var d_af56 "Dwelling: temporary shelter, shak or tent [=1]"
la var incometype_af_a "Income from wage labor (Somoni)"
la var incometype_af_b "Income from self-employment (Somoni)"
la var incometype_af_c "Income from livestock or crops (Somoni)"
la var incometype_af_d "Income from handcrafted products (Somoni)"
la var incometype_af_e "Income from remittances (Somoni)"
la var incometype_af_g "Income from a loan (Somoni) "
la var assets_af_a "Number of refrigerators in the HH."
la var assets_af_b "Number of washing machine in the HH."
la var assets_af_c "Number of AC in the HH."
la var assets_af_d "Number of fan in the HH."
la var assets_af_e "Number of stoves in the HH."
la var assets_af_f "Number of bread oven in the HH."
la var assets_af_g "Number of gas heaters in the HH."
la var assets_af_h "Number of microwaves in the HH."
la var assets_af_i "Number of radios in the HH."
la var assets_af_j "Number of TVs in the HH."
la var assets_af_k "Number of computers in the HH."
la var assets_af_l "Number of bicycles in the HH."
la var assets_af_m "Number of motorbikes in the HH."
la var assets_af_n "Number of cars and other vehicles in the HH." 
la var assets_af_o "Number of mobile phone in the HH."
la var assets_af_p "Sqm plot of land in the HH."
la var assets_af_q "Number of livestock or farm equipment in the HH."
la var assets_af_r "Number of place of business in the HH."
la var assets_af_s "Number of business assets in the HH."
la var sdrhypsochost "Feel Comfortable if your Child Socialize with Host Children"
la var sdrwelcomed "Feel Welcomed in this City"
la var sdrbelonging  "Feel Part of this Village"
la var sd_tajikhome "Feel that Tajikistan in your Home"
la var sd_frefugee "Number of Refugee Friends"
la var sd_fhost "Number of Tajikistan Friends"


****Same Variables in Afghanistan and Tajikistan
la var male "Male (% of Pop)"
la var hhsize "Household Size in Tajikistan"
la var hhsizeafg "Household Size in Afghanistan"

la def male 1 "Male" 0 "Female"
la val male male

lab define educ_level 1 "No education" 2 "Primary" 3 "Secondary" 4 "University or More"
lab val educ_level educ_level

lab var age "Age"
lab var male "Male (% of Pop)"

la def occupation 1 "Manager" 2 "Professional" 3 "Technicians" 4 "Clerks" ///
 5 "Services or Sales Worker" 6 "Skilled Agricultural" ///
 7 "Craft worker" 8 "Machine Operators" 9 "Elementary Occupation", replace
la val occupation occupation

la var friends "Friends before Moving to Tajikistan [=1]"
la var hhsizeafg "Household Size in Afghanistan"
la var hours_work_af "Weekly Hours Work in Afghanistan"
la var contract_af "Labor Contract in Afghanistan [=1]"
la var wages_af "Monthly Wage in Afghanistan (Somoni)"
la var house_af "Own a Dwelling in Afghanistan [=1]"

g yearseduc=0 if educ_level==1
replace yearseduc=6 if educ_level==2
replace yearseduc=9 if educ_level==3
replace yearseduc=11 if educ_level==4
replace yearseduc=12 if educ_level==5
replace yearseduc=13 if educ_level==6
replace yearseduc=16 if educ_level==7
replace yearseduc=19 if educ_level==8

la var yearseduc "Years of Education"

g id2=1
bys submission__id: egen nchildren=total(id2) if age>=0 & age<16

g female=1-male
g taliban_female=taliban_pr*female
g contested_female=contested_pr*female
g government_female=government_pr*female


save"../DataBase/final_base", replace























